pub struct GenericActions<Head: Clone + Display, Leaf: Clone + PartialEq + Eq + Display + Hash>(pub Vec<GenericAction<Head, Leaf>>);Tuple Fields
0: Vec<GenericAction<Head, Leaf>>Implementations
Sourceimpl<Head, Leaf> GenericActions<Head, Leaf>
impl<Head, Leaf> GenericActions<Head, Leaf>
pub fn len(&self) -> usize
pub fn is_empty(&self) -> bool
pub fn iter(&self) -> impl Iterator<Item = &GenericAction<Head, Leaf>>
pub fn visit_vars(&self, f: &mut impl FnMut(&Span, &Leaf))
Sourcepub fn visit_exprs(
self,
f: &mut impl FnMut(GenericExpr<Head, Leaf>) -> GenericExpr<Head, Leaf>,
) -> Self
pub fn visit_exprs( self, f: &mut impl FnMut(GenericExpr<Head, Leaf>) -> GenericExpr<Head, Leaf>, ) -> Self
Transforms every expression appearing in the action list using f.
Sourcepub fn visit_actions(
self,
f: &mut impl FnMut(GenericAction<Head, Leaf>) -> GenericAction<Head, Leaf>,
) -> Self
pub fn visit_actions( self, f: &mut impl FnMut(GenericAction<Head, Leaf>) -> GenericAction<Head, Leaf>, ) -> Self
Rewrites each action in the collection with the provided closure.
pub fn new(actions: Vec<GenericAction<Head, Leaf>>) -> Self
pub fn singleton(action: GenericAction<Head, Leaf>) -> Self
Sourcepub fn map_symbols<Head2, Leaf2>(
self,
head: &mut impl FnMut(Head) -> Head2,
leaf: &mut impl FnMut(Leaf) -> Leaf2,
) -> GenericActions<Head2, Leaf2>
pub fn map_symbols<Head2, Leaf2>( self, head: &mut impl FnMut(Head) -> Head2, leaf: &mut impl FnMut(Leaf) -> Leaf2, ) -> GenericActions<Head2, Leaf2>
Applies the provided head and leaf mappings to each action.
Sourcepub fn make_unresolved(self) -> GenericActions<String, String>
pub fn make_unresolved(self) -> GenericActions<String, String>
Converts the actions into their unresolved representation by formatting heads and leaves.